@@ -1,5 +1,6 @@
+from .authorizations import Authorization
 from .principalgroups import PrincipalGroup
 from .resourceauthorizations import ResourceAuthorization
 from .subjects import Subject
-from .subjectroles import SubjectRole
+from .subjectroletypes import SubjectRoleType
 from .usersubjects import User
